# frozen_string_literal: true

# Namespace for classes and modules that handle Bond calculation
#  @since 0.0.1
module BondCalculator

  # Bond is a PORO that represent the structure of benchmark and curve cvs's header
  #
  # @author Lucas Sant' Anna
  # @since 0.0.1
  class Bond
    attr_reader :name, :type, :term_years, :yield_percent

    # @param [Hash] args The options to create a Bond with
    #
    # @option args [String] :type Type of the Bond currencty we 
    #   implement the calculation for corporate and government only.
    # @option args [String] :bond Name of the company who is offering the Bond.
    # @option args [String] :term Number of years to pay.
    # @option args [String] :yield The interest rate.
    #
    # @return [<void>]
    def initialize(args)
      @type = format_type(args['type'])
      @name = format_bond(args['bond'])
      @term_years = format_term(args['term'])
      @yield_percent = format_yield(args['yield'])
    end

    private

    def format_type(type)
      type
    end

    def format_bond(name)
      name
    end

    def format_term(term)
      term.split(' ').first.to_f unless term.nil?
    end

    def format_yield(yield_percent)
      yield_percent&.delete('%').to_f
    end
  end
end
